aboutsummaryrefslogtreecommitdiffstats
path: root/library/blueimp_upload/js/jquery.fileupload-jquery-ui.js
diff options
context:
space:
mode:
authorzotlabs <mike@macgirvin.com>2017-06-26 17:32:38 -0700
committerzotlabs <mike@macgirvin.com>2017-06-26 17:32:38 -0700
commita8374b25f15c1c7545748bae26dda5e3c190573c (patch)
tree57bc976d9dd798e3c73f14399132822d3abfff8d /library/blueimp_upload/js/jquery.fileupload-jquery-ui.js
parent4d81c498e2f9a65eac7f71b077aa3e787d53325d (diff)
downloadvolse-hubzilla-a8374b25f15c1c7545748bae26dda5e3c190573c.tar.gz
volse-hubzilla-a8374b25f15c1c7545748bae26dda5e3c190573c.tar.bz2
volse-hubzilla-a8374b25f15c1c7545748bae26dda5e3c190573c.zip
upgrade blueimp from 9.8 to 9.18
Diffstat (limited to 'library/blueimp_upload/js/jquery.fileupload-jquery-ui.js')
-rw-r--r--[-rwxr-xr-x]library/blueimp_upload/js/jquery.fileupload-jquery-ui.js19
1 files changed, 14 insertions, 5 deletions
diff --git a/library/blueimp_upload/js/jquery.fileupload-jquery-ui.js b/library/blueimp_upload/js/jquery.fileupload-jquery-ui.js
index af0a00b1e..7b136b379 100755..100644
--- a/library/blueimp_upload/js/jquery.fileupload-jquery-ui.js
+++ b/library/blueimp_upload/js/jquery.fileupload-jquery-ui.js
@@ -1,22 +1,31 @@
/*
- * jQuery File Upload jQuery UI Plugin 8.7.1
+ * jQuery File Upload jQuery UI Plugin
* https://github.com/blueimp/jQuery-File-Upload
*
* Copyright 2013, Sebastian Tschan
* https://blueimp.net
*
* Licensed under the MIT license:
- * http://www.opensource.org/licenses/MIT
+ * https://opensource.org/licenses/MIT
*/
/* jshint nomen:false */
-/* global define, window */
+/* global define, require, window */
-(function (factory) {
+;(function (factory) {
'use strict';
if (typeof define === 'function' && define.amd) {
// Register as an anonymous AMD module:
- define(['jquery', './jquery.fileupload-ui'], factory);
+ define([
+ 'jquery',
+ './jquery.fileupload-ui'
+ ], factory);
+ } else if (typeof exports === 'object') {
+ // Node/CommonJS:
+ factory(
+ require('jquery'),
+ require('./jquery.fileupload-ui')
+ );
} else {
// Browser globals:
factory(window.jQuery);